import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 组织层次结构服务对象基类
 *
 * @export
 * @class HROMHierarchyServiceBase
 * @extends {EntityServie}
 */
export default class HROMHierarchyServiceBase extends EntityService {

    /**
     * Creates an instance of  HROMHierarchyServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  HROMHierarchyServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof HROMHierarchyServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='hromhierarchy';
        this.APPDEKEY = 'omhierarchyid';
        this.APPDENAME = 'hromhierarchies';
        this.APPDETEXT = 'organizationname';
        this.APPNAME = 'pim';
        this.SYSTEMNAME = 'ibizhumanresources';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && context.hromhierarchy){
            let res:any = Http.getInstance().get(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/${context.hromhierarchy}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/hromhierarchies/${context.hromhierarchy}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/hromhierarchies`,data,isloading);
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && context.hromhierarchy){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/${context.hromhierarchy}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/hromhierarchies/${context.hromhierarchy}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && context.hromhierarchy){
            let res:any = Http.getInstance().delete(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/${context.hromhierarchy}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/hromhierarchies/${context.hromhierarchy}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && context.hromhierarchy){
            let res:any = await Http.getInstance().get(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/${context.hromhierarchy}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/hromhierarchies/${context.hromhierarchy}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && true){
            let res:any = await Http.getInstance().get(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/getdraft`,isloading);
            res.data.hromhierarchy = data.hromhierarchy;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/hromhierarchies/getdraft`,isloading);
        res.data.hromhierarchy = data.hromhierarchy;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && context.hromhierarchy){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/${context.hromhierarchy}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/hromhierarchies/${context.hromhierarchy}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && context.hromhierarchy){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/${context.hromhierarchy}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/hromhierarchies/${context.hromhierarchy}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hromhierarchies/fetchdefault`,tempData,isloading);
        return res;
    }

    /**
     * FetchRootOrg接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HROMHierarchyServiceBase
     */
    public async FetchRootOrg(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hromhierarchycat && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/hromhierarchycats/${context.hromhierarchycat}/hromhierarchies/fetchrootorg`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hromhierarchies/fetchrootorg`,tempData,isloading);
        return res;
    }
}